@@ -13,7 +13,7 @@ G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (3)
 #define SOUP_MINOR_VERSION (0)
-#define SOUP_MICRO_VERSION (3)
+#define SOUP_MICRO_VERSION (4)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -32,7 +32,7 @@ G_BEGIN_DECLS
 #  ifdef G_PLATFORM_WIN32
 #    ifdef LIBSOUP_COMPILATION
 #      ifdef DLL_EXPORT
-#        define SOUP_VAR __declspec(dllexport)
+#        define SOUP_VAR extern __declspec(dllexport)
 #      else /* !DLL_EXPORT */
 #        define SOUP_VAR extern
 #      endif /* !DLL_EXPORT */
